UPM-Spatial-Interpolation
Python code and example data for Uncertainty Projected Mapping (UPM) as a spatial interpolation tool

The main code to generate UPM is UPM.py

There is also a simple flowchart (How to use the codes?.pdf) on how to use the codes. Please also find a file named The UPM story.pdf, which I created to provide an easy recap of UPM.

References on UPM:

Chakraborty, A., & Goto, H. (2018). A Bayesian model reflecting uncertainties on map resolutions with application to the study of site response variation. Geophysical Journal International, 214(3), 2264-2276.

Chakraborty, A., & Goto, H. (2020). Visualizing data saturation process in mapping site amplification of earthquake ground motions. Journal of Natural Disaster Science, 40(2), 14-25.

Chakraborty, A., Goto, H., & Sawada, S. (2024). Updating proxy-based site amplification map with in-situ data in Osaka, Japan: A Bayesian scheme based on uncertainty projected mapping. Earthquake Spectra, 2024;40(1):113-142.

References on CAR:

De Oliveira, V. (2012). Bayesian analysis of conditional autoregressive models. Annals of the Institute of Statistical Mathematics, 64, 107-133.